==> qt6-webengine_6.8.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.8.2/src/3rdparty/chromium/chrome/browser/resources/password_manager/password_manager.ts <==
// Copyright 2022 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './password_manager_app.js';

export {SettingsPrefsElement} from 'chrome://resources/cr_components/settings_prefs/prefs.js';
export {CrSettingsPrefs} from 'chrome://resources/cr_components/settings_prefs/prefs_types.js';
export {CrButtonElement} from 'chrome://resources/cr_elements/cr_button/cr_button.js';
export {CrDialogElement} from 'chrome://resources/cr_elements/cr_dialog/cr_dialog.js';
export {CrExpandButtonElement} from 'chrome://resources/cr_elements/cr_expand_button/cr_expand_button.js';
export {CrInputElement} from 'chrome://resources/cr_elements/cr_input/cr_input.js';
export {OpenWindowProxyImpl} from 'chrome://resources/js/open_window_proxy.js';
export {PluralStringProxy, PluralStringProxyImpl} from 'chrome://resources/js/plural_string_proxy.js';
export {CredentialFieldElement} from './credential_details/credential_field.js';
export {CredentialNoteElement} from './credential_details/credential_note.js';
export {PasskeyDetailsCardElement} from './credential_details/passkey_details_card.js';
export {PASSWORD_SHARE_BUTTON_BUTTON_ELEMENT_ID, PasswordDetailsCardElement} from './credential_details/password_details_card.js';
export {AddPasswordDialogElement} from './dialogs/add_password_dialog.js';
export {AuthTimedOutDialogElement} from './dialogs/auth_timed_out_dialog.js';
export {DeletePasskeyDialogElement} from './dialogs/delete_passkey_dialog.js';
export {EditPasskeyDialogElement} from './dialogs/edit_passkey_dialog.js';
export {EditPasswordDialogElement} from './dialogs/edit_password_dialog.js';
// <if expr="is_win or is_macosx">
export {PasskeysBrowserProxy, PasskeysBrowserProxyImpl} from './passkeys_browser_proxy.js';
// </if>
export {PasswordDetailsSectionElement} from './password_details_section.js';
export {PasswordListItemElement} from './password_list_item.js';
export {PasswordManagerAppElement} from './password_manager_app.js';
export {AccountStorageOptInStateChangedListener, BlockedSite, BlockedSitesListChangedListener, CredentialsChangedListener, PasswordCheckInteraction, PasswordCheckStatusChangedListener, PasswordManagerAuthTimeoutListener, PasswordManagerImpl, PasswordManagerProxy, PasswordsFileExportProgressListener, PasswordViewPageInteractions} from './password_manager_proxy.js';
export {PasswordsExporterElement} from './passwords_exporter.js';
export {PasswordsImporterElement} from './passwords_importer.js';
export {PasswordsSectionElement} from './passwords_section.js';
export {PrefToggleButtonElement} from './prefs/pref_toggle_button.js';
export {PromoCard, PromoCardsProxy, PromoCardsProxyImpl} from './promo_cards/promo_cards_browser_proxy.js';
export {CheckupSubpage, Page, Route, RouteObserverMixin, RouteObserverMixinInterface, Router, UrlParam} from './router.js';
export {SettingsSectionElement} from './settings_section.js';
export {SharePasswordConfirmationDialogElement} from './sharing/share_password_confirmation_dialog.js';
export {ShareFlowState, SharePasswordFlowElement} from './sharing/share_password_flow.js';
export {SharePasswordGroupAvatarElement} from './sharing/share_password_group_avatar.js';
export {SharePasswordLoadingDialogElement} from './sharing/share_password_loading_dialog.js';
export {SharePasswordRecipientElement} from './sharing/share_password_recipient.js';
export {PasswordManagerSideBarElement} from './side_bar.js';
export {SiteFaviconElement} from './site_favicon.js';
export {AccountInfo, SyncBrowserProxy, SyncBrowserProxyImpl, SyncInfo, TrustedVaultBannerState} from './sync_browser_proxy.js';
export {PasswordManagerToolbarElement} from './toolbar.js';

==> qt6-webengine_6.9.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.9.2/src/3rdparty/chromium/chrome/browser/resources/password_manager/password_manager.ts <==
// Copyright 2022 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './password_manager_app.js';

export {SettingsPrefsElement} from '/shared/settings/prefs/prefs.js';
export {CrSettingsPrefs} from '/shared/settings/prefs/prefs_types.js';
export {CrButtonElement} from 'chrome://resources/cr_elements/cr_button/cr_button.js';
export {CrDialogElement} from 'chrome://resources/cr_elements/cr_dialog/cr_dialog.js';
export {CrExpandButtonElement} from 'chrome://resources/cr_elements/cr_expand_button/cr_expand_button.js';
export {CrInputElement} from 'chrome://resources/cr_elements/cr_input/cr_input.js';
export {OpenWindowProxyImpl} from 'chrome://resources/js/open_window_proxy.js';
export {PluralStringProxy, PluralStringProxyImpl} from 'chrome://resources/js/plural_string_proxy.js';
export {CredentialFieldElement} from './credential_details/credential_field.js';
export {CredentialNoteElement} from './credential_details/credential_note.js';
export {PasskeyDetailsCardElement} from './credential_details/passkey_details_card.js';
export {PASSWORD_SHARE_BUTTON_BUTTON_ELEMENT_ID, PasswordDetailsCardElement} from './credential_details/password_details_card.js';
export {AddPasswordDialogElement, PASSWORD_NOTE_MAX_CHARACTER_COUNT} from './dialogs/add_password_dialog.js';
export {AuthTimedOutDialogElement} from './dialogs/auth_timed_out_dialog.js';
export {DeletePasskeyDialogElement} from './dialogs/delete_passkey_dialog.js';
export {DisconnectCloudAuthenticatorDialogElement} from './dialogs/disconnect_cloud_authenticator_dialog.js';
export {EditPasskeyDialogElement} from './dialogs/edit_passkey_dialog.js';
export {EditPasswordDialogElement} from './dialogs/edit_password_dialog.js';
export {FullDataResetElement} from './full_data_reset.js';
// <if expr="is_win or is_macosx">
export {PasskeysBrowserProxy, PasskeysBrowserProxyImpl} from './passkeys_browser_proxy.js';
// </if>
export {PasswordDetailsSectionElement} from './password_details_section.js';
export {PasswordListItemElement} from './password_list_item.js';
export {PasswordManagerAppElement} from './password_manager_app.js';
export {AccountStorageOptInStateChangedListener, BlockedSite, BlockedSitesListChangedListener, CredentialsChangedListener, PasswordCheckInteraction, PasswordCheckStatusChangedListener, PasswordManagerAuthTimeoutListener, PasswordManagerImpl, PasswordManagerProxy, PasswordsFileExportProgressListener, PasswordViewPageInteractions} from './password_manager_proxy.js';
export {PasswordsExporterElement} from './passwords_exporter.js';
export {PasswordsImporterElement} from './passwords_importer.js';
export {PasswordsSectionElement} from './passwords_section.js';
export {PrefToggleButtonElement} from './prefs/pref_toggle_button.js';
export {PromoCard, PromoCardsProxy, PromoCardsProxyImpl} from './promo_cards/promo_cards_browser_proxy.js';
export {CheckupSubpage, Page, Route, RouteObserverMixin, RouteObserverMixinInterface, Router, UrlParam} from './router.js';
export {PASSWORD_MANAGER_ACCOUNT_STORE_TOGGLE_ELEMENT_ID, SettingsSectionElement} from './settings_section.js';
export {SharePasswordConfirmationDialogElement} from './sharing/share_password_confirmation_dialog.js';
export {ShareFlowState, SharePasswordFlowElement} from './sharing/share_password_flow.js';
export {SharePasswordGroupAvatarElement} from './sharing/share_password_group_avatar.js';
export {SharePasswordLoadingDialogElement} from './sharing/share_password_loading_dialog.js';
export {SharePasswordRecipientElement} from './sharing/share_password_recipient.js';
export {PasswordManagerSideBarElement} from './side_bar.js';
export {SiteFaviconElement} from './site_favicon.js';
export {AccountInfo, SyncBrowserProxy, SyncBrowserProxyImpl, SyncInfo, TrustedVaultBannerState} from './sync_browser_proxy.js';
export {PasswordManagerToolbarElement} from './toolbar.js';
